{{title}}

This 'scribble' application illustrates with a simple 'TODO' example how to use the library flux-view to create reactive UI. We tried to reproduce as much as possible the example of Vue.

The code source of this file is located /home/greinisch/Projects/platform/py-youwol/test_install/.test_venv/lib/python3.6/site-packages/youwol_data/workspace/frontends/scribbles/tutu on your computer: do not hesitate to update it and refresh this page.

If you want to use other library/framework (e.g. React, Vue, etc) you may want to use a regular typescript project. You can also check if youwol pipelines already exists (search for yw_pipeline in pipy)

Double click on an item to edit.